summaryrefslogtreecommitdiff
path: root/sw/source/filter/ww8/ww8par6.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/filter/ww8/ww8par6.cxx')
-rw-r--r--sw/source/filter/ww8/ww8par6.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 5328487e1313..e6105c2ff5ad 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -2148,12 +2148,12 @@ void WW8SwFlyPara::BoxUpWidth( tools::Long nInWidth )
nNewNetWidth = nInWidth;
};
// The class WW8FlySet is derived from SfxItemSet and does not
// provide more, but is easier to handle for me.
// WW8FlySet-ctor for Apos and graphics Apos
WW8FlySet::WW8FlySet(SwWW8ImplReader& rReader, const WW8FlyPara* pFW,
const WW8SwFlyPara* pFS, bool bGraf)
- : SfxItemSet(rReader.m_rDoc.GetAttrPool(),svl::Items<RES_FRMATR_BEGIN,RES_FRMATR_END-1>)
+ : SfxItemSetFixed(rReader.m_rDoc.GetAttrPool())
{
Reader::ResetFrameFormatAttrs(*this); // remove distance/border
// position
@@ -2208,7 +2208,7 @@ WW8FlySet::WW8FlySet(SwWW8ImplReader& rReader, const WW8FlyPara* pFW,
// WW8FlySet-ctor for character bound graphics
WW8FlySet::WW8FlySet( SwWW8ImplReader& rReader, const SwPaM* pPaM,
const WW8_PIC& rPic, tools::Long nWidth, tools::Long nHeight )
- : SfxItemSet(rReader.m_rDoc.GetAttrPool(),svl::Items<RES_FRMATR_BEGIN,RES_FRMATR_END-1>)
+ : SfxItemSetFixed<RES_FRMATR_BEGIN,RES_FRMATR_END-1>(rReader.m_rDoc.GetAttrPool())
{
Init(rReader, pPaM);
@@ -2260,8 +2260,8 @@ void WW8FlySet::Init(const SwWW8ImplReader& rReader, const SwPaM* pPaM)
WW8DupProperties::WW8DupProperties(SwDoc &rDoc, SwWW8FltControlStack *pStack)
: pCtrlStck(pStack),
- aChrSet(rDoc.GetAttrPool(), svl::Items<RES_CHRATR_BEGIN, RES_CHRATR_END - 1> ),
- aParSet(rDoc.GetAttrPool(), svl::Items<RES_PARATR_BEGIN, RES_PARATR_END - 1> )
+ aChrSet(rDoc.GetAttrPool()),
+ aParSet(rDoc.GetAttrPool())
{
//Close any open character properties and duplicate them inside the
//first table cell
@@ -2148,12 +2148,12 @@ void WW8SwFlyPara::BoxUpWidth( tools::Long nInWidth )
nNewNetWidth = nInWidth;
};
-// The class WW8FlySet is derived from SfxItemSet and does not
+// The class WW8FlySet is derived from SfxItemSetFixed and does not
// provide more, but is easier to handle for me.
// WW8FlySet-ctor for Apos and graphics Apos